repo stringclasses 15
values | fix_commit stringlengths 40 40 | buggy_commit stringlengths 40 40 | message stringlengths 3 64.3k | files listlengths 1 300 | timestamp timestamp[s]date 2013-03-13 20:45:00 2026-04-11 07:48:46 |
|---|---|---|---|---|---|
ollama/ollama | 70a93057cdfcc660684db556d2044c9497651778 | b2816bca67ae5e47f1c285c5ee72929769932585 | refactor layer creation
previous layer creation was not ideal because:
1. it required reading the input file multiple times, once to calculate
the sha256 checksum, another to write it to disk, and potentially one
more to decode the underlying gguf
2. used io.ReadSeeker which is prone to user error. if the file ... | [
{
"path": "server/images.go",
"patch": "@@ -19,8 +19,6 @@ import (\n \t\"strings\"\n \t\"text/template\"\n \n-\t\"golang.org/x/exp/slices\"\n-\n \t\"github.com/jmorganca/ollama/api\"\n \t\"github.com/jmorganca/ollama/llm\"\n \t\"github.com/jmorganca/ollama/parser\"\n@@ -128,22 +126,10 @@ func (m *Model) Cha... | 2023-11-22T21:28:49 |
vuejs/vue | 0b2f11036d86f1242370726fec230db77a49d95e | d6bd667e1a984378cf27d688f69b02a1f7332482 | fix typo (#5667) | [
{
"path": "packages/vue-server-renderer/README.md",
"patch": "@@ -4,5 +4,5 @@\n \n This package offers Node.js server-side rendering for Vue 2.0.\n \n-- [API Reference](ssr.vuejs.org/en/api.html)\n+- [API Reference](https://ssr.vuejs.org/en/api.html)\n - [Vue.js Server-Side Rendering Guide](https://ssr.vuej... | 2017-05-14T03:53:12 |
denoland/deno | 0baa1a65746e97dd030e291f65c3013b936b0462 | f7cb82042ad14573ceb1dac261607f7a5ff764c4 | fix(ext/node): add `worker.cpuUsage([prev])` API (#32050) | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -4,6 +4,7 @@\n import { core, internals, primordials } from \"ext:core/mod.js\";\n import {\n op_create_worker,\n+ op_host_get_worker_cpu_usage,\n op_host_post_message,\n op_host_recv_ctrl,\n op_host_recv_message,\n@@ -25,6 +26,12 @@ im... | 2026-02-05T12:09:13 |
ggml-org/llama.cpp | 7f3e9d339c99d96d6df9833c63ec27dbbc96f003 | 8a3519b70898b07ec05c391418a05aaa6b377c83 | vulkan: iGPU memory reporting fix (#17110)
* vulkan: use all device-local heaps for memory availability reporting
Co-authored-by: Giuseppe Scrivano <gscrivan@redhat.com>
* use all available heaps for iGPU memory reporting
* Allow multiple memory types per buffer request for devices with split heaps
---------
Co-a... | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -2159,17 +2159,18 @@ static void ggml_vk_queue_command_pools_cleanup(vk_device& device) {\n }\n }\n \n+static std::vector<uint32_t> ggml_vk_find_memory_properties(const vk::PhysicalDeviceMemoryProperties* mem_props, vk::MemoryRequirements* m... | 2025-11-09T08:54:47 |
huggingface/transformers | 8f242a45b1059f8c821ea19971bec2d379d9cb93 | 1c2e50a72e310d315cd84920c4c55660c6b8f0a3 | [deepspeed tests fixes] (#41925)
* [deepspeed tests fixes]
Signed-off-by: Stas Bekman <stas.bekman@snowflake.com>
* simplify
---------
Signed-off-by: Stas Bekman <stas.bekman@snowflake.com>
Co-authored-by: Stas Bekman <stas.bekman@snowflake.com> | [
{
"path": "tests/deepspeed/test_deepspeed.py",
"patch": "@@ -756,13 +756,9 @@ def test_gradient_accumulation(self, stage, dtype):\n self.assertNotEqual(yes_grad_accum_a, a)\n \n # training with half the batch size but accumulation steps as 2 should give the same\n- # weights, but ... | 2025-11-06T15:24:22 |
vuejs/vue | 38759a695779b74065947f2cc3e0c010d50c2c6c | 8d54aecdd04202d39659a7625eef846673064ab3 | fix test case in IE | [
{
"path": "test/unit/modules/vdom/create-element.spec.js",
"patch": "@@ -170,12 +170,12 @@ describe('create-element', () => {\n return h('div', [[...list, input]])\n }\n }).$mount()\n- expect(vm.$el.innerHTML).toBe('<span>0</span><input value=\"a\" type=\"text\">')\n+ expect(vm.$el.i... | 2017-05-09T16:37:41 |
denoland/deno | f7cb82042ad14573ceb1dac261607f7a5ff764c4 | 83d7b0c5ec1248d6af17bd73f061bce576e96e64 | fix(ext/node): propagate worker exit code from process.exit() (#32061)
Enables `test-worker-esm-exit.js` test
---------
Signed-off-by: Divy <dj.srivastava23@gmail.com> | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -249,7 +249,7 @@ class NodeWorker extends EventEmitter {\n this.#status = \"CLOSED\";\n if (!this.#exited) {\n this.#exited = true;\n- this.emit(\"exit\", 0);\n+ this.emit(\"exit\", data ?? 0... | 2026-02-05T09:05:17 |
huggingface/transformers | 1c2e50a72e310d315cd84920c4c55660c6b8f0a3 | 5aa7dd07dace2dbe5d419613ec9b43b36df35f89 | Fix missing arg in check_docstring (#42054)
fix missing arg in check_docstring | [
{
"path": "src/transformers/utils/auto_docstring.py",
"patch": "@@ -240,6 +240,14 @@ class ImageProcessorArgs:\n \"shape\": None,\n }\n \n+ image_seq_length = {\n+ \"description\": \"\"\"\n+ The number of image tokens to be used for each image in the input.\n+ Added for backward ... | 2025-11-06T14:38:04 |
ggml-org/llama.cpp | 8a3519b70898b07ec05c391418a05aaa6b377c83 | 80a6cf63473b95742444a1b27d45164591282a7d | vulkan: fix mmq out of bounds reads (#17108)
* vulkan: fix mmq out of bounds reads, streamline outdated matmul host code
* fix mul_mat_id quantization call
* Fix compiler warnings | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -586,7 +586,6 @@ struct vk_device_struct {\n vk_matmul_pipeline2 pipeline_dequant_mul_mat_mat_id_q8_1[GGML_TYPE_COUNT];\n \n vk_pipeline pipeline_matmul_split_k_reduce;\n- vk_pipeline pipeline_quantize_q8_1;\n vk_pipeline pipeline... | 2025-11-09T08:52:57 |
ollama/ollama | 95cb38ae474848f5c5787916344a96def8c7ce81 | 1f126afb2d5c742e5534a10d4d518b74ea1f2bf7 | install: fix rocky kernel packages | [
{
"path": "scripts/install.sh",
"patch": "@@ -217,7 +217,7 @@ fi\n \n if ! check_gpu nvidia-smi || [ -z \"$(nvidia-smi | grep -o \"CUDA Version: [0-9]*\\.[0-9]*\")\" ]; then\n case $OS_NAME in\n-\tcentos|rhel) install_cuda_driver_yum 'rhel' $(echo $OS_VERSION | cut -d '.' -f 1) ;;\n+ centos|rhel)... | 2023-12-02T00:18:21 |
vuejs/vue | 8d54aecdd04202d39659a7625eef846673064ab3 | 3139605bb10fed0a0219e31a2117c533e31fe773 | async components: timeout should not trigger if already resolved (fix #5635) | [
{
"path": "src/core/vdom/helpers/resolve-async-component.js",
"patch": "@@ -97,11 +97,13 @@ export function resolveAsyncComponent (\n \n if (isDef(res.timeout)) {\n setTimeout(() => {\n- reject(\n- process.env.NODE_ENV !== 'production'\n- ? `timeout (... | 2017-05-09T15:35:09 |
denoland/deno | 83d7b0c5ec1248d6af17bd73f061bce576e96e64 | 2a46e203ddbbff5840cbb14ee2a77893c05bdb24 | fix(ext/node): Fix `.only` tests compatibilty (#32043)
Only tests in Node.js are filtered from running instead of erroring out.
This patch adds an option in Deno's test runner to skip santizing only
tests. | [
{
"path": "cli/js/40_test.js",
"patch": "@@ -314,6 +314,7 @@ function testInner(\n testDesc.location.lineNumber,\n testDesc.location.columnNumber,\n registerTestIdRetBufU8,\n+ testDesc.sanitizeOnly ?? true,\n );\n testDesc.id = registerTestIdRetBuf[0];\n testDesc.origin = cachedOrigin;"... | 2026-02-05T09:03:22 |
ggml-org/llama.cpp | 333f2595a3e0e4c0abf233f2f29ef1710acd134d | 53d7d21e6128af43020190100b7f91d7bdce93c5 | webui: fix keyboard shortcuts for new chat & edit chat title (#17007) | [
{
"path": "tools/server/webui/src/routes/+layout.svelte",
"patch": "@@ -44,12 +44,12 @@\n \t\t\t}\n \t\t}\n \n-\t\tif (isCtrlOrCmd && event.shiftKey && event.key === 'o') {\n+\t\tif (isCtrlOrCmd && event.shiftKey && event.key === 'O') {\n \t\t\tevent.preventDefault();\n \t\t\tgoto('?new_chat=true#/');\n \t\... | 2025-11-08T19:52:35 |
huggingface/transformers | 5aa7dd07dace2dbe5d419613ec9b43b36df35f89 | 5c1df12fa5d3f9fa5e19b72e1ba34903813d1ce7 | Revert back to use GitHub context (#42066)
* check
* fix
---------
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": ".github/workflows/pr_slow_ci_suggestion.yml",
"patch": "@@ -28,13 +28,15 @@ jobs:\n with:\n fetch-depth: \"0\"\n \n+ # We need to use `${{ ... }}` here to avoid `Argument list too long` error when a PR changes a lot of files.\n+ # (We could also try to use artifact app... | 2025-11-06T13:41:58 |
vuejs/vue | 0ccefff794c5fe73b80b9faf5ae5bfd8ec1a500f | dc00590bc56fc9b0afd50a11425486fb771402fc | support v-for on scoped slots (fix #5615) | [
{
"path": "flow/component.js",
"patch": "@@ -106,7 +106,7 @@ declare interface Component {\n // check custom keyCode\n _k: (eventKeyCode: number, key: string, builtInAlias: number | Array<number> | void) => boolean;\n // resolve scoped slots\n- _u: (scopedSlots: Array<[string, Function]>) => { [key: ... | 2017-05-09T15:00:15 |
denoland/deno | f84c762373bb2248924781e6a907847e54880fba | 533c5058380616b1755f1b42fb3c9a4c37a52f1c | fix(ext/node): handle raw fd instead rid in isatty (#31912)
Previously, isatty(fd) was calling core.isTerminal(fd) which expected a Deno resource ID, but Node.js APIs pass raw OS file descriptors. For fd 0, 1, 2 (stdin/stdout/stderr) this happened to work because rid === fd, but it would fail for higher fds. | [
{
"path": "ext/node/lib.rs",
"patch": "@@ -369,6 +369,7 @@ deno_core::extension!(deno_node,\n ops::require::op_require_package_imports_resolve<TInNpmPackageChecker, TNpmPackageFolderResolver, TSys>,\n ops::require::op_require_break_on_next_statement,\n ops::util::op_node_guess_handle_type,\n+ ... | 2026-02-04T20:03:29 |
ggml-org/llama.cpp | eeee367de51fb34d46c8103fc0ae827e84d94470 | 64fe17fbb84f493dbc33e4c13042953c4f5bfaeb | server: fix correct time_ms calculation in prompt_progress (#17093)
* fix: correct time_ms calculation in send_partial_response
The time_ms field was incorrectly calculated. The division was happening
before the subtraction leading to incorrect values.
Before: (ggml_time_us() - slot.t_start_process_prompt / 1000) Af... | [
{
"path": "tools/server/README.md",
"patch": "@@ -512,7 +512,7 @@ These words will not be included in the completion, so make sure to add them to\n \n `timings_per_token`: Include prompt processing and text generation speed information in each response. Default: `false`\n \n-`return_progress`: Include prom... | 2025-11-08T13:12:11 |
huggingface/transformers | 5c1df12fa5d3f9fa5e19b72e1ba34903813d1ce7 | fe5ca9ddaa07fac2872407e75c7a7661216ac956 | Fix KeyError in _is_package_available for packages with dotted names (#42050)
Fixes #41981
When checking for packages with dotted names like 'optimum.quanto', the
function was crashing with KeyError because these packages aren't always
in PACKAGE_DISTRIBUTION_MAPPING (it might only have 'optimum' as a key,
not 'optim... | [
{
"path": "src/transformers/utils/import_utils.py",
"patch": "@@ -58,7 +58,7 @@ def _is_package_available(pkg_name: str, return_version: bool = False) -> tuple[\n # pick the first item of the list as best guess (it's almost always a list of length 1 anyway)\n distribution_name = pkg_... | 2025-11-06T13:32:43 |
vuejs/vue | f2bd882073919add805bf359ecdf632faf9abfcd | 5d965d5b3bbe0e76cdb97e41e01a704322253e09 | Fix: nested child elements can not be updated correctly, fix #5618 (#5627)
* fix:nested elements can not be updated correctly
* add tests
* ensure nestedIndex is always passed down | [
{
"path": "src/core/instance/render-helpers/render-list.js",
"patch": "@@ -1,6 +1,6 @@\n /* @flow */\n \n-import { isObject } from 'core/util/index'\n+import { isObject, isDef } from 'core/util/index'\n \n /**\n * Runtime helper for rendering v-for lists.\n@@ -28,5 +28,8 @@ export function renderList (\n ... | 2017-05-09T15:21:49 |
ollama/ollama | bb80a597dbb3dcdcb8465d7813aa4fe3905a4be2 | 6681d378617fa83da16861c06f8439304b1188f8 | Fix adapter loading from SHA hash | [
{
"path": "server/images.go",
"patch": "@@ -375,6 +375,15 @@ func CreateModel(ctx context.Context, name, modelFileDir string, commands []pars\n \t\t\tlayer.MediaType = mediatype\n \t\t\tlayers = append(layers, layer)\n \t\tcase \"adapter\":\n+\t\t\tif strings.HasPrefix(c.Args, \"@\") {\n+\t\t\t\tblobPath, e... | 2023-12-01T18:50:55 |
denoland/deno | 533c5058380616b1755f1b42fb3c9a4c37a52f1c | 943b45b4bc5de51bfddf5e7a1eb9d68939d8bb23 | feat(upgrade): add context to error messages for better troubleshooting (#32018)
Fixes denoland/deno#31995
---------
Co-authored-by: copilot-swe-agent[bot] <198982749+Copilot@users.noreply.github.com>
Co-authored-by: bartlomieju <13602871+bartlomieju@users.noreply.github.com>
Co-authored-by: Bartek Iwańczuk <biwancz... | [
{
"path": "cli/tools/upgrade.rs",
"patch": "@@ -484,7 +484,8 @@ pub async fn upgrade(\n let factory = CliFactory::from_flags(flags);\n let http_client_provider = factory.http_client_provider();\n let client = http_client_provider.get_or_create()?;\n- let current_exe_path = std::env::current_exe()?;\n... | 2026-02-04T18:42:26 |
huggingface/transformers | fe5ca9ddaa07fac2872407e75c7a7661216ac956 | 76fea9b482a2e8b8d104e66675afabcb1173c80d | Fix KeyError in GPT-OSS weight conversion script (#42007)
* Fix KeyError in GPT-OSS weight conversion script
* Fix code quality: remove trailing whitespace
* Address review: use pop with defaults, remove commented code | [
{
"path": "src/transformers/models/gpt_oss/convert_gpt_oss_weights_to_hf.py",
"patch": "@@ -157,14 +157,24 @@ def write_model(\n original_config = json.loads((Path(input_base_path) / \"config.json\").read_text())\n \n num_local_experts = original_config.pop(\"num_experts\")\n- rope_parameters = {... | 2025-11-06T12:43:39 |
ggml-org/llama.cpp | d6fe40fa0040bf7207b2380d0f3628fb56d6a86f | e14e842e87103ec2a004770cec95a3f94f861bda | vulkan: Fix test-thread-safety crashes (#17024)
The std::map pipeline_flash_attn_f32_f16 could be searched and inserted at the
same time, which needs to hold the lock. To be safe, hold the lock for all of
ggml_vk_load_shaders. | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -130,9 +130,9 @@ struct vk_pipeline_struct {\n // true if fields have been set by ggml_vk_create_pipeline\n bool initialized {};\n // set to true to request the pipeline is compiled\n- bool needed {};\n+ std::atomic<bool> neede... | 2025-11-08T07:39:45 |
vuejs/vue | 1c40e327062452fc9c934e728b70014810653b6a | ca02043194c7f464e65559347bc6ee2539554762 | Fix use mixin API feat continuous operation (#5610)
* Update use.js
fix:use feat continuous operation
* Update mixin.js
fix:mixin feat continuous operation | [
{
"path": "src/core/global-api/mixin.js",
"patch": "@@ -5,5 +5,6 @@ import { mergeOptions } from '../util/index'\n export function initMixin (Vue: GlobalAPI) {\n Vue.mixin = function (mixin: Object) {\n this.options = mergeOptions(this.options, mixin)\n+ return this\n }\n }",
"additions": 1,
... | 2017-05-09T12:23:38 |
ollama/ollama | 5687f1a0cfa3d2408bfcb04f4342f657f6dada58 | 7eda3d0c55baab6a481eb3348586d93b299d467b | fix `unexpected end of response` errors when cancelling in `ollama run` | [
{
"path": "cmd/cmd.go",
"patch": "@@ -496,12 +496,10 @@ func generate(cmd *cobra.Command, opts generateOptions) error {\n \n \tsigChan := make(chan os.Signal, 1)\n \tsignal.Notify(sigChan, syscall.SIGINT)\n-\tvar abort bool\n \n \tgo func() {\n \t\t<-sigChan\n \t\tcancel()\n-\t\tabort = true\n \t}()\n \n \t... | 2023-11-30T05:30:16 |
denoland/deno | 943b45b4bc5de51bfddf5e7a1eb9d68939d8bb23 | 846c34e119d4c8600ff41f42446e3633c7bd3a75 | fix(ext/node): implement Symbol.asyncDispose for node Worker (#32051)
Fixes parallel/test-worker-dispose.mjs test | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -49,6 +49,7 @@ const {\n StringPrototypeStartsWith,\n StringPrototypeTrim,\n Symbol,\n+ SymbolAsyncDispose,\n SymbolFor,\n SymbolIterator,\n TypeError,\n@@ -339,6 +340,10 @@ class NodeWorker extends EventEmitter {\n return Promi... | 2026-02-04T17:10:05 |
ggml-org/llama.cpp | e14e842e87103ec2a004770cec95a3f94f861bda | 647b960bd8017ee882d6633bc2e43e2ae82ee85c | CUDA: fix MMQ stream-k fixup ne1 indices (#17089) | [
{
"path": "ggml/src/ggml-cuda/mmq.cuh",
"patch": "@@ -3494,7 +3494,7 @@ static __global__ void mul_mat_q_stream_k_fixup(\n const int col_diff = col_high - col_low;\n \n for (int j = threadIdx.y*warp_size + threadIdx.x; j < mmq_x; j += nwarps*warp_size) {\n- ids_dst_shared[j] = ids_dst[col_low... | 2025-11-08T07:26:18 |
huggingface/transformers | 76fea9b482a2e8b8d104e66675afabcb1173c80d | 8a96f5fbe814ad88e333855b2ef39c62cd961c6f | Fix another `Argument list too long` in `pr_slow_ci_suggestion.yml` (#42061)
* fix
* trigger
---------
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": ".github/workflows/pr_slow_ci_suggestion.yml",
"patch": "@@ -29,12 +29,12 @@ jobs:\n fetch-depth: \"0\"\n \n - name: Write pr_files file\n- env:\n- PR_FILES: ${{ needs.get-pr-info.outputs.PR_FILES }}\n- run: |\n- cat > pr_files.txt << EOF\n- ... | 2025-11-06T12:33:23 |
vuejs/vue | d52a4991bd6cd28d57c42c97446d27cbb36416e5 | 9ac4c4188d03fec51337b257a95954f0d3fa30a0 | Prevent unecessary input trigger with v-model (#5589)
* Prevent unecessary input trigger with v-model
Fix #5586
* Add test for compositionend on v-model + @input
* [skip ci] Rename tests for compositionend | [
{
"path": "src/platforms/web/runtime/directives/model.js",
"patch": "@@ -119,6 +119,8 @@ function onCompositionStart (e) {\n }\n \n function onCompositionEnd (e) {\n+ // prevent triggering an input event for no reason\n+ if (!e.target.composing) return\n e.target.composing = false\n trigger(e.target, ... | 2017-05-07T13:46:33 |
ollama/ollama | 13efd5f2188f9e43600b9efef14fce21995b7a51 | c4bdfffd96da9fc4b0f7c97d2a79f5497469539b | upload: fix PUT retry | [
{
"path": "server/upload.go",
"patch": "@@ -194,24 +194,22 @@ func (b *blobUpload) Run(ctx context.Context, opts *RegistryOptions) {\n \theaders.Set(\"Content-Length\", \"0\")\n \n \tfor try := 0; try < maxRetries; try++ {\n-\t\tresp, err := makeRequestWithRetry(ctx, http.MethodPut, requestURL, headers, nil... | 2023-11-29T23:18:53 |
denoland/deno | 4f776721191a91d58845ded6a4236ca84f04cf22 | 60814fb3995f096bab2713f052e740b2049ef41d | fix: `deno info` npm subpath import (#32056)
Prevent circular redirects in the output of `deno info --json` | [
{
"path": "cli/tools/info.rs",
"patch": "@@ -345,8 +345,11 @@ fn add_npm_packages_to_json(\n .map(|path| format!(\"/{}\", path))\n .unwrap_or_default()\n );\n- redirects_to_add\n- .push((specifier.to_string(), new_specifier.clone()));\n+ ... | 2026-02-04T16:53:27 |
ggml-org/llama.cpp | 65156105069fa86a4a81b6cb0e8cb583f6420677 | 7956bb4d7f430f23f3c4726f7e6404b89f6e20a4 | CUDA: fix should_use_mmvf for ne11 == 1 (#17085)
* CUDA: fix should_use_mmvf for ne11 == 1
* Apply suggestion from @am17an
Co-authored-by: Aman Gupta <amangupta052@gmail.com>
---------
Co-authored-by: Aman Gupta <amangupta052@gmail.com> | [
{
"path": "ggml/src/ggml-cuda/mmf.cu",
"patch": "@@ -129,7 +129,13 @@ bool ggml_cuda_should_use_mmf(enum ggml_type type, int cc, int warp_size, const\n if (src0_ne[0] % (warp_size * (4/ts)) != 0) {\n return false;\n }\n- for (size_t i = 0; i < GGML_MAX_DIMS; ++i) {\n+\n+ if (src0_nb[0]... | 2025-11-07T19:53:14 |
huggingface/transformers | 21ecb5b0b8be61a51c476856589c45f10d3e8568 | 40929ec4fdc5708520eef134b9b86f5393e1b59e | Fix transformers serve following chat template output update | [
{
"path": "src/transformers/cli/serve.py",
"patch": "@@ -813,7 +813,7 @@ def continuous_batching_chat_completion(self, req: dict, request_id: str) -> Str\n # TODO (Joao, Lysandre): this should also work with tool support\n inputs = processor.apply_chat_template(req[\"messages\"], return_tens... | 2025-11-05T16:20:58 |
vuejs/vue | 9ac4c4188d03fec51337b257a95954f0d3fa30a0 | 5c0c8c886520133e99d837a7a7161ced233f5120 | fix #5591: keep ssr template interpolation whitespace-insensitive (#5597) | [
{
"path": "src/server/template-renderer/parse-template.js",
"patch": "@@ -2,7 +2,7 @@\n \n const compile = require('lodash.template')\n const compileOptions = {\n- escape: /{{[^{]([\\s\\S]+?)[^}]}}/g,\n+ escape: /{{([^{][\\s\\S]+?[^}])}}/g,\n interpolate: /{{{([\\s\\S]+?)}}}/g\n }\n ",
"additions": ... | 2017-05-07T13:43:02 |
ollama/ollama | 39be7fdb98cdcdfb1da0753410bccfc30cfa9c0d | c2e3b891760686d163b701be564dcbcab87a8785 | fix rhel cuda install (#1321)
Co-authored-by: Cloud User <azureuser@testgpu2.hqzwom21okjenksna4y3c4ymjd.phxx.internal.cloudapp.net> | [
{
"path": "scripts/install.sh",
"patch": "@@ -217,7 +217,7 @@ fi\n \n if ! check_gpu nvidia-smi || [ -z \"$(nvidia-smi | grep -o \"CUDA Version: [0-9]*\\.[0-9]*\")\" ]; then\n case $OS_NAME in\n- centos|rhel) install_cuda_driver_yum 'rhel' $OS_VERSION ;;\n+\tcentos|rhel) install_cuda_driver_yum '... | 2023-11-29T19:55:15 |
denoland/deno | 60814fb3995f096bab2713f052e740b2049ef41d | 4a9ae62b521f06b57b923e48a15113274cc897a6 | fix(node/crypto): randomBytes returns buffer with dedicated ArrayBuffer (#32048)
Fixes denoland/deno#32047
---------
Co-authored-by: copilot-swe-agent[bot] <198982749+Copilot@users.noreply.github.com>
Co-authored-by: bartlomieju <13602871+bartlomieju@users.noreply.github.com>
Co-authored-by: littledivy <34997667+lit... | [
{
"path": "ext/node/polyfills/internal/crypto/_randomBytes.ts",
"patch": "@@ -24,7 +24,7 @@ function generateRandomBytes(size: number) {\n );\n }\n \n- const bytes = Buffer.allocUnsafe(size);\n+ const bytes = Buffer.allocUnsafeSlow(size);\n \n //Work around for getRandomValues max generation\n i... | 2026-02-04T16:13:36 |
ggml-org/llama.cpp | aa374175c30184aeb1813ec71fc68780dd073906 | 5b180c3d60f3df61cd9955bc5c69e64537958f92 | CUDA: fix crash on uneven context without FA (#16988) | [
{
"path": "ggml/src/ggml-cuda/ggml-cuda.cu",
"patch": "@@ -2113,7 +2113,7 @@ static bool ggml_cuda_should_fuse_mul_mat_vec_f(const ggml_tensor * tensor) {\n src1->type == GGML_TYPE_F32 && dst->type == GGML_TYPE_F32;\n \n const int cc = ggml_cuda_info().devices[ggml_cuda_get_device()].cc;\n-... | 2025-11-06T13:05:47 |
huggingface/transformers | 40929ec4fdc5708520eef134b9b86f5393e1b59e | 17fdaf9b7a8a172474675e1d7fe89c78385fa79b | Annoying typo in attention error message (#42037)
annoying typo | [
{
"path": "src/transformers/modeling_utils.py",
"patch": "@@ -2424,7 +2424,7 @@ def get_correct_attn_implementation(self, requested_attention: Optional[str], is\n if self._supports_flash_attn or getattr(self, \"_supports_flash_attn_2\", False):\n message += ', `\"attn_implementat... | 2025-11-06T08:57:17 |
ollama/ollama | c2e3b891760686d163b701be564dcbcab87a8785 | cde31cb220f0d3b4b6eba75faf854a542a332384 | fix: disable ':' in tag names (#1280)
Co-authored-by: rootedbox | [
{
"path": "server/routes.go",
"patch": "@@ -416,6 +416,11 @@ func CreateModelHandler(c *gin.Context) {\n \t\treturn\n \t}\n \n+\tif strings.Count(req.Name, \":\") > 1 {\n+\t\tc.AbortWithStatusJSON(http.StatusBadRequest, gin.H{\"error\": \"':' (colon) is not allowed in tag names\"})\n+\t\treturn\n+\t}\n+\n \... | 2023-11-29T18:33:45 |
ggml-org/llama.cpp | 5b180c3d60f3df61cd9955bc5c69e64537958f92 | b7f9010d24766792d8887c227a883ed3b315d2be | metal : initial Metal4 tensor API support (#16634)
* metal : rework mat-mat multiplication
* metal : initial Metal4 support
* cont
* metal : detect tensor support
* cont : better ifdefs
* metal : support tensors in mul_mm_id
* metal : add env for disabling tensor API
* tests : restore
* metal : remove unused c... | [
{
"path": "ggml/src/ggml-metal/ggml-metal-context.m",
"patch": "@@ -35,7 +35,6 @@\n // additional, inference-time compiled pipelines\n ggml_metal_pipelines_t pipelines_ext;\n \n- bool use_bfloat;\n bool use_fusion;\n bool use_concurrency;\n bool use_graph_optimize;\n@@ -121,11 +120,10... | 2025-11-06T12:45:10 |
denoland/deno | 4a9ae62b521f06b57b923e48a15113274cc897a6 | 1b424993ce6e2fa5f7c89a691dd5d13f77977103 | fix: unstable_cron_socket_serve_reject flakiness caused by control socket coordination (#32053) | [
{
"path": "tests/specs/run/unstable_cron_socket_serve_reject/test_runner.js",
"patch": "@@ -23,8 +23,21 @@ const mainProcess = new Deno.Command(Deno.execPath(), {\n },\n }).spawn();\n \n-// Give Deno a moment to start and create its control socket\n-await new Promise((resolve) => setTimeout(resolve, 100))... | 2026-02-04T15:45:31 |
vuejs/vue | a8da4fb051bfc085e7e3781adbe6346b9db7d674 | b977c77d344cb1fc63a3daa50a4b96ef70e77ec5 | fix #5592: comment vnode should not be merged into text vnode. (#5593)
* comment vnode should not be merged into text vnode.
* add isFalse helper
* delete trailing spaces | [
{
"path": "src/core/vdom/helpers/normalize-children.js",
"patch": "@@ -1,7 +1,7 @@\n /* @flow */\n \n import VNode, { createTextVNode } from 'core/vdom/vnode'\n-import { isDef, isUndef, isPrimitive } from 'shared/util'\n+import { isFalse, isDef, isUndef, isPrimitive } from 'shared/util'\n \n // The template... | 2017-05-07T13:39:04 |
huggingface/transformers | 85c50557b97590538229f99a321ea88d03d6eaa7 | 32e49f2884cdc23c172513d1a2cafe0f03255591 | Fix Qwen3-Omni RoPE (#41778)
* fix qwen rope
* not sure it fits in runners, let's see
* fix some tests
* use input ids device everywhere
* fix rope in wav2code and the test
* I remember pushing these changes yesterday | [
{
"path": "src/transformers/models/qwen3_omni_moe/configuration_qwen3_omni_moe.py",
"patch": "@@ -347,6 +347,7 @@ def __init__(\n tie_word_embeddings=tie_word_embeddings,\n **kwargs,\n )\n+ rope_config_validation(self, ignore_keys={\"mrope_section\", \"interleaved\", \... | 2025-11-06T08:30:39 |
huggingface/transformers | 32e49f2884cdc23c172513d1a2cafe0f03255591 | bb65d2d953a512609a86727b6de64035717b1d45 | Fix AutoImageProcessor.register and documentation in auto processing modules (#41864) | [
{
"path": "src/transformers/models/auto/feature_extraction_auto.py",
"patch": "@@ -93,7 +93,7 @@ def feature_extractor_class_from_name(class_name: str):\n if getattr(extractor, \"__name__\", None) == class_name:\n return extractor\n \n- # We did not fine the class, but maybe it's beca... | 2025-11-06T07:43:07 |
vuejs/vue | cab1b151e25ffbfdd5bd3745e4932746e5cca691 | 2a1f79dfbe9a3a6241f1060ce53616ffeb12fdc6 | avoid swallowing webpack error when entry is not found (fix #5553) | [
{
"path": "src/server/webpack-plugin/server.js",
"patch": "@@ -13,7 +13,14 @@ export default class VueSSRServerPlugin {\n compiler.plugin('emit', (compilation, cb) => {\n const stats = compilation.getStats().toJson()\n const entryName = Object.keys(stats.entrypoints)[0]\n- const entryAs... | 2017-04-30T04:44:23 |
ggml-org/llama.cpp | 4882f0ff786088871b3ab3abd9e525a4213ee218 | 9d7c518d642db8657e2a53a9793c5f039ed8ea5a | clip: implement minicpm-v sinusoidal embd using GGML (#17036)
* clip: implement minicpm-v sinusoidal embd using GGML
* fix repeat op | [
{
"path": "tools/mtmd/clip.cpp",
"patch": "@@ -1083,16 +1083,24 @@ struct clip_graph {\n }\n \n ggml_cgraph * build_minicpmv() {\n- const int batch_size = 1;\n-\n GGML_ASSERT(model.class_embedding == nullptr);\n- const int n_pos = n_patches;\n+ const int n_pos = n_... | 2025-11-06T10:02:54 |
denoland/deno | 1b424993ce6e2fa5f7c89a691dd5d13f77977103 | 12134b0c470607fe4483a6188c2b02b19ca5a2a0 | fix(audit): make 'Path' property more readable (#32049)
Makes report more readable by adding spaces in `Path` property.
Before:
```
╭ @denotest/with-vuln2 can steal crypto keys
│ Severity: critical
│ Package: @edenotest/with-vuln2
│ Vulnerable: <2.0.0
│ Patched: >=2.0.0
│ Path: @denotest/using-vuln>@den... | [
{
"path": "cli/tools/pm/audit.rs",
"patch": "@@ -404,7 +404,11 @@ mod npm {\n if let Some(finding) = adv.findings.first()\n && let Some(path) = finding.paths.first()\n {\n- _ = writeln!(stdout, \"│ {} {}\", colors::gray(\"Path:\"), path);\n+ let path_fmt = path\n+ ... | 2026-02-04T13:34:47 |
ollama/ollama | 424d53ac70d1960770f3bb3a7aa44afea9f2dbeb | e1a69d44c9c9adae94a54e123a7118915d6bbf4e | progress: fix bar rate | [
{
"path": "format/bytes.go",
"patch": "@@ -37,6 +37,8 @@ func HumanBytes(b int64) string {\n \tswitch {\n \tcase value >= 100:\n \t\treturn fmt.Sprintf(\"%d %s\", int(value), unit)\n+\tcase value >= 10:\n+\t\treturn fmt.Sprintf(\"%d %s\", int(value), unit)\n \tcase value != math.Trunc(value):\n \t\treturn f... | 2023-11-19T00:23:03 |
huggingface/transformers | bb65d2d953a512609a86727b6de64035717b1d45 | 57bdb4a680b2f82ad739ef741996be04e3764eea | Fix `pr_slow_ci_suggestion.yml` after #42023 (#42049)
fix
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": ".github/workflows/pr_slow_ci_suggestion.yml",
"patch": "@@ -23,11 +23,26 @@ jobs:\n outputs:\n jobs: ${{ steps.get_jobs.outputs.jobs_to_run }}\n steps:\n+ # This checkout to the main branch\n+ - uses: actions/checkout@v4\n+ with:\n+ fetch-depth: \"0\"\n+\n+... | 2025-11-05T21:10:12 |
vuejs/vue | 2a1f79dfbe9a3a6241f1060ce53616ffeb12fdc6 | 9478fde8c92d225661dcb4c949d0035284600fff | run bundle in the same global context when runInNewContext is false (fix #5559) | [
{
"path": "src/server/bundle-renderer/create-bundle-runner.js",
"patch": "@@ -22,7 +22,7 @@ function createContext (context) {\n return sandbox\n }\n \n-function compileModule (files, basedir) {\n+function compileModule (files, basedir, runInNewContext) {\n const compiledScripts = {}\n const resolvedM... | 2017-04-30T04:39:00 |
ggml-org/llama.cpp | 9d7c518d642db8657e2a53a9793c5f039ed8ea5a | 22c8c3c6ad8d6239c366ce3a84ace8b0ac59ef88 | sycl: add CONCAT operator support (#16047)
* sycl: add CONCAT operator support
* cleanup: remove stray lines added by mistake
* fix: code format issues in concat.cpp and tests/test-backend-ops.cpp
* chore: fix editorconfig violations
* cleanup: drop unnecessary i16 type support
* docs: update sycl-csv and regener... | [
{
"path": "docs/ops.md",
"patch": "@@ -24,7 +24,7 @@ Legend:\n | ARGSORT | ❌ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ❌ |\n | CEIL | ❌ | ❌ | ✅ | 🟡 | ❌ | ❌ | ✅ | ❌ | ❌ |\n | CLAMP | ❌ | ✅ | ✅ | ✅ | 🟡 | 🟡 | ✅ | 🟡 | ❌ |\n-| ... | 2025-11-06T10:02:33 |
denoland/deno | 12134b0c470607fe4483a6188c2b02b19ca5a2a0 | 9aca4f6c5331f0ced1ae1071211056608572932a | fix(ext/node): fix multiple node:zlib compatibility issues (#32039)
These fixes bring back number of failing `node:zlib` tests down to 8. | [
{
"path": "ext/node/ops/zlib/mod.rs",
"patch": "@@ -357,6 +357,22 @@ impl Zlib {\n Ok(zlib.err)\n }\n \n+ #[fast]\n+ pub fn params(\n+ &self,\n+ #[smi] level: i32,\n+ #[smi] strategy: i32,\n+ ) -> Result<(), ZlibError> {\n+ let mut zlib = self.inner.borrow_mut();\n+ let zlib = zlib.a... | 2026-02-04T11:57:41 |
ollama/ollama | e1a69d44c9c9adae94a54e123a7118915d6bbf4e | 3d620f9462b800b880d51e0eb6e51a91182f79db | Update faq.md (#1299)
Fix a typo in the CA update command | [
{
"path": "docs/faq.md",
"patch": "@@ -139,7 +139,7 @@ Ensure the certificate is installed as a system certificate when using HTTPS. Th\n ```dockerfile\n FROM ollama/ollama\n COPY my-ca.pem /usr/local/share/ca-certificates/my-ca.crt\n-RUN update-ca-certificate\n+RUN update-ca-certificates\n ```\n \n Build a... | 2023-11-28T14:54:42 |
vuejs/vue | 3b426efe60c30b0fd52144c65b28603b5e4511db | bb7c543fc20c63809da0a7f530b3da1bf8f2f14e | Fix when functional component render method retrun null (fix #5536) (#5539)
* fix:create empty vnode when functional component return null
* add test
* use isDef | [
{
"path": "src/core/vdom/create-element.js",
"patch": "@@ -99,7 +99,7 @@ export function _createElement (\n // direct component options / constructor\n vnode = createComponent(tag, data, context, children)\n }\n- if (vnode !== undefined) {\n+ if (isDef(vnode)) {\n if (ns) applyNS(vnode, ns)\... | 2017-04-29T06:42:35 |
ollama/ollama | e9216ea459f3fabaef81f376ddbf0ba6ef292b37 | 9e4a316405d9c5ea37ee21bba4f99573db276c70 | fix readline history on linux | [
{
"path": "readline/history.go",
"patch": "@@ -43,9 +43,12 @@ func (h *History) Init() error {\n \t}\n \n \tpath := filepath.Join(home, \".ollama\", \"history\")\n+\tif err := os.MkdirAll(filepath.Dir(path), 0o755); err != nil {\n+\t\treturn err\n+\t}\n+\n \th.Filename = path\n \n-\t//todo check if the file... | 2023-11-26T20:59:04 |
ggml-org/llama.cpp | a44d77126c911d105f7f800c17da21b2a5b112d1 | 5886f4f545591dafbbd9d6117a46d7399ce13bfa | vulkan: Fix GGML_VULKAN_CHECK_RESULTS to better handle fusion (#16919) | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -14104,30 +14104,18 @@ size_t comp_size;\n size_t comp_nb[GGML_MAX_DIMS];\n size_t check_counter = 0;\n static void ggml_vk_check_results_0(ggml_backend_vk_context * ctx, ggml_cgraph * cgraph, int tensor_idx) {\n- ggml_tensor * tensor = cgrap... | 2025-11-05T18:51:03 |
denoland/deno | 9aca4f6c5331f0ced1ae1071211056608572932a | 72b9709c7d70ed059d1afc45c68736e930de5266 | fix(ext/node): add hasColors() to process.stdout and process.stderr (#31985)
## Summary
- Adds `hasColors()` method to `process.stdout` and `process.stderr`
- Fixes Node.js compatibility issue where packages like Commander.js
check color support
Fixes #27278
## Changes
- Modified `ext/node/polyfills/_process/streams... | [
{
"path": "ext/node/polyfills/_process/streams.mjs",
"patch": "@@ -25,6 +25,7 @@ import { Duplex, Readable, Writable } from \"node:stream\";\n import * as io from \"ext:deno_io/12_io.js\";\n import { guessHandleType } from \"ext:deno_node/internal_binding/util.ts\";\n import { op_bootstrap_color_depth } fro... | 2026-02-04T10:48:08 |
huggingface/transformers | 57bdb4a680b2f82ad739ef741996be04e3764eea | 1a0ae4bb81caf000e655cd326712377f777a7a74 | Cleanup workflow - part 1 (#42023)
* part 1
* part 2
* part 3
* part 4
* part 5
* fix 1
* check 1
* part 6
* part 7
* part 8
* part 9
* part 10: rename file
* OK: new_model_pr_merged_notification.yml
* part 11
* fix 2
* revert check
* fix
* fix
* fix
---------
Co-authored-by: ydshieh <ydshieh@users... | [
{
"path": ".github/workflows/check_failed_tests.yml",
"patch": "@@ -64,13 +64,15 @@ jobs:\n - name: Check file\n id: check_file\n working-directory: /transformers\n+ env:\n+ job: ${{ inputs.job }}\n run: |\n- if [ -f ci_results_${{ inputs.job }}/new_fai... | 2025-11-05T20:01:06 |
vuejs/vue | bb7c543fc20c63809da0a7f530b3da1bf8f2f14e | 1635ca7143381265c0fb1cb197e0dbfa5d8b6365 | fix #5539: improve `isDef` type definition (#5549)
* fix #5539: improve flow type coverage
* skip unnecessary object creation
* use flow internal syntax to enable predicate type | [
{
"path": "flow/component.js",
"patch": "@@ -42,7 +42,7 @@ declare interface Component {\n $once: (event: string, fn: Function) => Component;\n $off: (event?: string | Array<string>, fn?: Function) => Component;\n $emit: (event: string, ...args: Array<mixed>) => Component;\n- $nextTick: (fn: Function... | 2017-04-29T06:24:06 |
ggml-org/llama.cpp | 13b339bcd91de64d59512f308f6f69eaca688103 | 2f0c2db43e2adfa9ffbdfa1176b3b6bd9c9ed536 | server : do not default to multiple slots with speculative decoding (#17017)
* server : do not default to multiple slots with speculative decoding
* cont : fix | [
{
"path": "common/common.h",
"patch": "@@ -507,6 +507,10 @@ struct common_params {\n // return false from callback to abort model loading or true to continue\n llama_progress_callback load_progress_callback = NULL;\n void * load_progress_callback_user_data = NULL;\n+\n+ bool ... | 2025-11-05T12:32:55 |
huggingface/transformers | 2418196ef41255cb686125a5f148ac44619c8622 | 561233cabf480b0f884700be3aebf42dbe6a7b20 | Fix the order of methods in processor loading (#42031)
* fix the order
* add a test | [
{
"path": "src/transformers/processing_utils.py",
"patch": "@@ -1370,8 +1370,8 @@ def from_pretrained(\n if token is not None:\n kwargs[\"token\"] = token\n \n- processor_dict, kwargs = cls.get_processor_dict(pretrained_model_name_or_path, **kwargs)\n args = cls._get_argum... | 2025-11-05T14:33:07 |
denoland/deno | 72b9709c7d70ed059d1afc45c68736e930de5266 | b2690b072780c79e3584406f8f9891e201734f00 | fix(ext/node): implement Node worker BroadcastChannel ref/unref (#32036)
All except one test case in
`parallel/test-worker-broadcastchannel-wpt.js` passes. Node.js message
dispatch ordering is not same as the Web api as explained in this
comment:
```js
// Messages are delivered in port creation order.
// TODO(@jas... | [
{
"path": "ext/node/polyfills/worker_threads.ts",
"patch": "@@ -26,7 +26,10 @@ import {\n import * as webidl from \"ext:deno_webidl/00_webidl.js\";\n import { notImplemented } from \"ext:deno_node/_utils.ts\";\n import { EventEmitter } from \"node:events\";\n-import { BroadcastChannel } from \"ext:deno_web/... | 2026-02-04T10:43:35 |
ollama/ollama | 9fb5e8399c61217a4deef60a773de19ebd87caca | 82b9b329ff84506445f85aed8d65690bd840831a | Fix issues with inputting and formatting multi line strings in `ollama run`
Co-authored-by: Wen Sun <iwendellsun@gmail.com> | [
{
"path": "cmd/cmd.go",
"patch": "@@ -602,22 +602,20 @@ func generateInteractive(cmd *cobra.Command, model string, wordWrap bool, format\n \t\tfmt.Fprintln(os.Stderr, \"\")\n \t}\n \n-\tprompt := readline.Prompt{\n+\tscanner, err := readline.New(readline.Prompt{\n \t\tPrompt: \">>> \",\n \t\tAltProm... | 2023-11-26T04:30:34 |
vuejs/vue | d8315c42ef5b6b739100fad5f20e8b0c41f78eef | 3a6fd13bc5c1c900774f759f200e064d60861b96 | do not decode text inside script/style tags (fix #5526) | [
{
"path": "src/compiler/parser/html-parser.js",
"patch": "@@ -46,7 +46,7 @@ let IS_REGEX_CAPTURING_BROKEN = false\n })\n \n // Special Elements (can contain anything)\n-const isPlainTextElement = makeMap('script,style,textarea', true)\n+export const isPlainTextElement = makeMap('script,style,textarea', true... | 2017-04-27T04:23:48 |
huggingface/transformers | 561233cabf480b0f884700be3aebf42dbe6a7b20 | 36b640562b11f54044841ae3665930023d4ff27d | Change trigger time for AMD CI (#42034)
fix
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": ".github/workflows/self-scheduled-amd-caller.yml",
"patch": "@@ -2,7 +2,7 @@ name: Self-hosted runner (AMD scheduled CI caller)\n \n on:\n schedule:\n- - cron: \"17 2 * * *\"\n+ - cron: \"17 5 * * *\"\n \n jobs:\n run_scheduled_amd_ci:",
"additions": 1,
"deletions": 1,
"langu... | 2025-11-05T13:17:12 |
ggml-org/llama.cpp | 9f052478c2c38ec10cb378109b110a1f7033ce11 | 03ea04175da3cdd7fd8cc1835f33490e3483928a | model : add openPangu-Embedded (#16941)
* Model: add openPangu-Embedded
* fixed according to reviewer's comments
* fixed the chat template check condition
* Apply suggestions from code review
change the chat-template check condition and some formatting issue
Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@s... | [
{
"path": "convert_hf_to_gguf.py",
"patch": "@@ -7187,6 +7187,42 @@ def modify_tensors(self, data_torch: Tensor, name: str, bid: int | None):\n return super().modify_tensors(data_torch, name, bid)\n \n \n+@ModelBase.register(\"PanguEmbeddedForCausalLM\")\n+class PanguEmbeddedModel(TextModel):\n+ ... | 2025-11-05T09:28:58 |
denoland/deno | b2690b072780c79e3584406f8f9891e201734f00 | 929ab331a754c695fb1c2fbb0182a2260f7b0d34 | fix(ext/node): implement `DatabaseSync.setAuthorizer()` (#32009) | [
{
"path": "ext/node/ops/sqlite/database.rs",
"patch": "@@ -516,6 +516,7 @@ pub struct DatabaseSync {\n options: DatabaseSyncOptions,\n location: String,\n ignore_next_sqlite_error: Rc<Cell<bool>>,\n+ authorizer_data: Rc<RefCell<Option<*mut AuthorizerData>>>,\n }\n \n // SAFETY: we're sure this can be... | 2026-02-04T10:42:44 |
vuejs/vue | c24f49254395f15e9f023202e98e9abe595b636e | 109689082741b3032196ad98779dd0943e8447a8 | fix edge test case | [
{
"path": "test/unit/modules/compiler/parser.spec.js",
"patch": "@@ -1,7 +1,7 @@\n import { parse } from 'compiler/parser/index'\n import { extend } from 'shared/util'\n import { baseOptions } from 'web/compiler/index'\n-import { isIE } from 'core/util/env'\n+import { isIE, isEdge } from 'core/util/env'\n \... | 2017-04-26T10:24:38 |
huggingface/transformers | 36b640562b11f54044841ae3665930023d4ff27d | 0c4a202408365681c114b127bf46aa2bbb4bcf8a | extend fp_quant cases to xpu (#41833)
* extend fp_quant UTs to xpu
Signed-off-by: Yao, Matrix <matrix.yao@intel.com>
* fix style
Signed-off-by: Yao, Matrix <matrix.yao@intel.com>
* Update tests/quantization/fp_quant_integration/test_fp_quant.py
Co-authored-by: Yih-Dar <2521628+ydshieh@users.noreply.github.com>
-... | [
{
"path": "src/transformers/quantizers/quantizer_fp_quant.py",
"patch": "@@ -20,7 +20,7 @@\n if TYPE_CHECKING:\n from ..modeling_utils import PreTrainedModel\n \n-from ..utils import is_fp_quant_available, is_qutlass_available, is_torch_available, logging\n+from ..utils import is_fp_quant_available, is_... | 2025-11-05T10:50:31 |
ggml-org/llama.cpp | 03ea04175da3cdd7fd8cc1835f33490e3483928a | cdabeb2c27232b5abd84210d57ac3bf33e7ebf5c | ggml webgpu: minor set rows optimization (#16810)
* Add buffer label and enable dawn-specific toggles to turn off some checks
* Minor set_rows optimization (#4)
* updated optimization, fixed errors
* non vectorized version now dispatches one thread per element
* Simplify
* Change logic for set_rows pipelines
---... | [
{
"path": "ggml/src/ggml-webgpu/ggml-webgpu.cpp",
"patch": "@@ -248,7 +248,7 @@ struct webgpu_context_struct {\n \n webgpu_pipeline memset_pipeline;\n webgpu_pipeline mul_mat_pipeline[30][2];\n- webgpu_pipeline set_rows_pipeline;\n+ webgpu_pipeline set_rows_pipeline[1][2]; // dst->type, vecto... | 2025-11-05T09:27:42 |
denoland/deno | 929ab331a754c695fb1c2fbb0182a2260f7b0d34 | d9bd0545a4c01a0b348a70b5dcee3d7cf56e33ce | fix(flags): extra trailing space in zsh directory completions (#32042)
Fixes https://github.com/denoland/deno/issues/31809
Ref
https://github.com/clap-rs/clap/commit/5571b83c8a322ee2cf4342402d930cf2806fa2f1 | [
{
"path": "cli/args/flags.rs",
"patch": "@@ -6844,7 +6844,25 @@ function _clap_dynamic_completer_NAME() {\n )}\")\n \n if [[ -n $completions ]]; then\n- _describe -V 'values' completions -o nosort\n+ local -a dirs=()\n+ local -a other=()\n+ local completion\n+ for completion in ... | 2026-02-04T10:07:53 |
vuejs/vue | 12b7122c161548bfc9865357d9b71302d66d4a9f | 2a247fcadc12c151e0bca7ee03254474cdba30b1 | fix mixin issue (#5514) | [
{
"path": "src/core/instance/init.js",
"patch": "@@ -115,24 +115,27 @@ export function resolveConstructorOptions (Ctor: Class<Component>) {\n function resolveModifiedOptions (Ctor: Class<Component>): ?Object {\n let modified\n const latest = Ctor.options\n+ const extended = Ctor.extendOptions\n const... | 2017-04-26T06:51:25 |
huggingface/transformers | 0c4a202408365681c114b127bf46aa2bbb4bcf8a | 20396951afaf35e12979e8ef54b2289936921ac6 | [tests] Add Context-parallel CI tests (#41860)
* intial
* simplify tests
* add test_cp_equivalence
* removed fsdp_transformer_layer_cls_to_wrap
* use DataCollatorForLanguageModeling
* remove use_cache=False.
* changes from review
* make script self contained
* moved to fsdp folder
* fix class name | [
{
"path": "tests/fsdp/test_context_parallel.py",
"patch": "@@ -0,0 +1,224 @@\n+# Copyright 2025 The HuggingFace Team. All rights reserved.\n+#\n+# Licensed under the Apache License, Version 2.0 (the \"License\");\n+# you may not use this file except in compliance with the License.\n+# You may obtain a copy ... | 2025-11-05T10:40:51 |
ggml-org/llama.cpp | 852ce5180acd4e3641f6b71783a343647eee058d | 9aa63374f2101f4eaef425888699907b238ed2c0 | ggml : fix conv2d_dw SVE path (ggml/1380)
* Fix test-conv2d-dw failure on ARM SVE by using runtime vector length
The ggml_compute_forward_conv_2d_dw_cwhn function was using a hardcoded GGML_F32_EPR (8) for SIMD vectorization, but on ARM SVE the actual vector length varies by hardware. This caused incorrect computatio... | [
{
"path": "ggml/src/ggml-cpu/ops.cpp",
"patch": "@@ -7084,7 +7084,11 @@ static void ggml_compute_forward_conv_2d_dw_cwhn(\n const int64_t row_end = MIN(row_start + rows_per_thread, rows_total);\n \n #ifdef GGML_SIMD\n- const int64_t pkg_size = GGML_F32_EPR;\n+ #if defined(__ARM_FEATURE_SVE)\n+ ... | 2025-11-04T18:40:52 |
denoland/deno | 478bc5a905048f3ccafc51369e61b4bdeffe5b5b | cec91f6c0e1e5e3259161e6d33365f6d790e1b8b | fix(ext/node): add stub for ServerResponse.writeEarlyHints (#32029)
Ref https://github.com/denoland/deno/issues/31176 | [
{
"path": "ext/node/polyfills/http.ts",
"patch": "@@ -1572,6 +1572,10 @@ export type ServerResponse = {\n end(chunk?: any, encoding?: any, cb?: any): void;\n \n flushHeaders(): void;\n+ writeEarlyHints(\n+ hints: Record<string, string | string[]>,\n+ callback?: () => void,\n+ ): void;\n _impli... | 2026-02-03T17:35:08 |
ollama/ollama | 12e8c12d2b5c0658cad014b58a8baf597b0741df | d77dde126b5fc6e340a9e65f1b9e33316a2c760c | Disable CUDA peer access as a workaround for multi-gpu inference bug (#1261)
When CUDA peer access is enabled, multi-gpu inference will produce
garbage output. This is a known bug of llama.cpp (or nvidia). Until the
upstream bug is fixed, we can disable CUDA peer access temporarily
to ensure correct output.
See ... | [
{
"path": "llm/llama.cpp/generate_linux.go",
"patch": "@@ -21,6 +21,6 @@ package llm\n //go:generate cmake -S ggml -B ggml/build/cuda -DLLAMA_CUBLAS=on -DLLAMA_ACCELERATE=on -DLLAMA_K_QUANTS=on\n //go:generate cmake --build ggml/build/cuda --target server --config Release\n //go:generate mv ggml/build/cuda/... | 2023-11-24T19:05:57 |
vuejs/vue | 2a247fcadc12c151e0bca7ee03254474cdba30b1 | 016920ebea8bbd3dc7c5326d6bc6590a6f4cc418 | fix ssr initial context style recording | [
{
"path": "src/server/bundle-renderer/create-bundle-runner.js",
"patch": "@@ -1,4 +1,4 @@\n-import { isObject } from 'shared/util'\n+import { isPlainObject } from 'shared/util'\n \n const vm = require('vm')\n const path = require('path')\n@@ -73,7 +73,7 @@ function compileModule (files, basedir) {\n }\n \n ... | 2017-04-25T08:53:28 |
ggml-org/llama.cpp | 5e90233bdba013838c1a69df7738e08bd5c058d5 | a5c07dcd7b49916c7c770f2da9583e6b82717678 | opencl: update doc (#17011)
* opencl: update docs
* opencl: update docs
* opencl: fix link
* opencl: update doc | [
{
"path": "docs/backend/OPENCL.md",
"patch": "@@ -39,25 +39,41 @@ The llama.cpp OpenCL backend is designed to enable llama.cpp on **Qualcomm Adren\n | Adreno 830 (Snapdragon 8 Elite) | Support |\n | Adreno X85 (Snapdragon X Elite) | Support |\n \n+> A6x GPUs with a recent driver and compiler are s... | 2025-11-05T00:02:36 |
denoland/deno | cec91f6c0e1e5e3259161e6d33365f6d790e1b8b | b486c63f282fe6c294097aaea9c809305bf7bea8 | fix(cli): pull in tunnel fix for windows (#32033) | [
{
"path": "Cargo.lock",
"patch": "@@ -3047,14 +3047,15 @@ dependencies = [\n \n [[package]]\n name = \"deno_tunnel\"\n-version = \"0.8.0\"\n+version = \"0.8.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"cbe45dacb6e0d2a646b22a12fea81ba2f7128202f9ee91602782b9208da123b... | 2026-02-03T16:21:25 |
vuejs/vue | 38516b494293a9ee9bae697d559107341dca89dd | 380e98882353d24afe34568b3e06c8a29de82a4a | fix flow | [
{
"path": "src/core/instance/render-helpers/resolve-slots.js",
"patch": "@@ -12,13 +12,13 @@ export function resolveSlots (\n return slots\n }\n const defaultSlot = []\n- let name, child\n for (let i = 0, l = children.length; i < l; i++) {\n- child = children[i]\n+ const child = children[i]... | 2017-04-25T04:28:20 |
ollama/ollama | 199941cd151fb789577af77776fc970c6db99a3a | 37d95157dfed0726d751d3a694e9d6cd3c923097 | fix: gguf int type | [
{
"path": "llm/gguf.go",
"patch": "@@ -335,7 +335,7 @@ func (llm *ggufModel) readArrayV1(r io.Reader) (arr []any, err error) {\n \t\tcase ggufTypeUint8:\n \t\t\tarr = append(arr, llm.readU8(r))\n \t\tcase ggufTypeInt8:\n-\t\t\tarr = append(arr, llm.readU8(r))\n+\t\t\tarr = append(arr, llm.readI8(r))\n \t\tc... | 2023-11-22T19:40:30 |
denoland/deno | b486c63f282fe6c294097aaea9c809305bf7bea8 | 0aa1fe12be1e3e71934eaf51037db67dcad00f37 | fix(ext/node): add zstd compression support to node:zlib (#32025)
This commit improves impl of `node:zlib` module by adding zstd
compression support.
Several Node compat tests were enabled, more will be enabled in a follow
up.
---------
Co-authored-by: Claude Opus 4.5 <noreply@anthropic.com> | [
{
"path": "Cargo.lock",
"patch": "@@ -2552,6 +2552,7 @@ dependencies = [\n \"x25519-dalek\",\n \"x509-parser\",\n \"yoke 0.7.4\",\n+ \"zstd\",\n ]\n \n [[package]]",
"additions": 1,
"deletions": 0,
"language": "Unknown"
},
{
"path": "ext/node/Cargo.toml",
"patch": "@@ -104,6 +104,... | 2026-02-03T15:35:17 |
ggml-org/llama.cpp | b164259bbaa579e1d82b2bc18be133947ac71290 | 1f5accb8d0056e6099cd5b772b1cb787dd590a13 | chore : fix models indent after refactor (#16992) | [
{
"path": "src/models/gemma2-iswa.cpp",
"patch": "@@ -1,125 +1,125 @@\n #include \"models.h\"\n \n llm_build_gemma2_iswa::llm_build_gemma2_iswa(const llama_model & model, const llm_graph_params & params) : llm_graph_context(params) {\n- const int64_t n_embd_head = hparams.n_embd_head_k;\n-\n- ... | 2025-11-04T11:29:15 |
denoland/deno | 0aa1fe12be1e3e71934eaf51037db67dcad00f37 | c006bba8061e2d96004823c64287515937b0897d | fix: add raw.esm.sh to default `--allow-import` list (#32030)
Closes https://github.com/denoland/deno/issues/31015 | [
{
"path": "cli/args/flags.rs",
"patch": "@@ -4574,7 +4574,7 @@ fn permission_args(app: Command, requires: Option<&'static str>) -> Command {\n <g>-W, --allow-write[=<<PATH>...]</> Allow file system write access. Optionally specify allowed paths.\n <p... | 2026-02-03T15:21:29 |
huggingface/transformers | 3c4cdd549d2b57c7f9d484122076f1bca9463d91 | 020e713ac8e70bd2e72bcd12dc6bd1ada6162562 | fix `deeepspeed` in AMD docker file (#42025)
fix deeepspeed in AMD docker
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": "docker/transformers-pytorch-deepspeed-amd-gpu/Dockerfile",
"patch": "@@ -29,7 +29,7 @@ RUN python3 -m pip uninstall -y apex torch torchvision torchaudio\n RUN python3 -m pip install torch==$PYTORCH torchvision==$TORCH_VISION torchaudio==$TORCH_AUDIO --index-url https://download.pytorch.org/whl/ro... | 2025-11-05T09:40:29 |
ollama/ollama | 37d95157dfed0726d751d3a694e9d6cd3c923097 | 2eaa95b417e0711f90fe298ef233e58c6fe0a478 | fix relative path on create (#1222) | [
{
"path": "server/images.go",
"patch": "@@ -228,27 +228,32 @@ func GetModel(name string) (*Model, error) {\n \treturn model, nil\n }\n \n-func realpath(p string) string {\n-\tabspath, err := filepath.Abs(p)\n+func realpath(mfDir, from string) string {\n+\tabspath, err := filepath.Abs(from)\n \tif err != nil... | 2023-11-21T20:43:17 |
ggml-org/llama.cpp | 1f5accb8d0056e6099cd5b772b1cb787dd590a13 | 2759ccdb4adc8568add4316780d5e675519b0775 | Fix garbled output with REPACK at high thread counts (#16956)
* Fix garbled output with REPACK at high thread counts
Fixed a race condition in the REPACK matrix multiplication code that caused garbled output when using 26+ threads (model-dependent threshold). The issue occurred because with high thread counts, the co... | [
{
"path": "ggml/src/ggml-cpu/repack.cpp",
"patch": "@@ -1678,10 +1678,24 @@ template <typename BLOC_TYPE, int64_t INTER_SIZE, int64_t NB_COLS, ggml_type PAR\n int64_t chunk_size = (nr + nth_scaled - 1) / nth_scaled;\n int64_t nchunk = (nr + chunk_size - 1) / chunk_size;\n \n+ // E... | 2025-11-04T05:04:59 |
vuejs/vue | c0da43d22f8f4b9aeb4f49d4e86cd9704daaff3f | af43862969fbe2ef01644eaac2a73a02039d69ad | fix incorrect compiler warning for $delete usage in templates (fix #5464) | [
{
"path": "src/compiler/error-detector.js",
"patch": "@@ -57,8 +57,9 @@ function checkNode (node: ASTNode, errors: Array<string>) {\n }\n \n function checkEvent (exp: string, text: string, errors: Array<string>) {\n- const keywordMatch = exp.replace(stripStringRE, '').match(unaryOperatorsRE)\n- if (keywor... | 2017-04-18T03:40:32 |
denoland/deno | 13a5674462ab9e7d8c532f5a85f2e5b9c2445ce2 | 0b38d25ba7c1893757e15fbb2a68537b0191321f | fix: flaky cron socket tests (#32023) | [
{
"path": "tests/specs/run/unstable_cron_socket_basic/server.js",
"patch": "@@ -45,8 +45,8 @@ outer: while (true) {\n setTimeout(async () => {\n const invocation =\n JSON.stringify({ kind: \"invoke\", name: firstCronName }) + \"\\n\";\n+ console.error(\"[CRON SERVER] I... | 2026-02-03T11:34:54 |
huggingface/transformers | 371ef0f4a2c5264f0b04270f07ee86c104c76f0a | 6efc1799c1d0665c41717c555f3551d974e4d61a | [v5] Deprecate Text2Text and related pipelines (#41996)
* Deprecate Text2Text and related pipelines
* Try a restructure
* make fixup
* logging -> logger | [
{
"path": "src/transformers/pipelines/__init__.py",
"patch": "@@ -59,6 +59,7 @@\n get_default_model_and_revision,\n load_model,\n )\n+from .deprecated import SummarizationPipeline, Text2TextGenerationPipeline, TranslationPipeline\n from .depth_estimation import DepthEstimationPipeline\n from .docume... | 2025-11-04T16:47:06 |
ollama/ollama | f2113c1fc79110c5f243a39cb5ac03590b67fed9 | 6452e2ecb83ae03b1c504e09b6ca3ce9868d0c45 | fix potential error in progress bar calculation | [
{
"path": "progress/bar.go",
"patch": "@@ -95,7 +95,10 @@ func (b *Bar) String() string {\n \t}\n \n \t// 44 is the maximum width for the stats on the right of the progress bar\n-\tsuf.WriteString(strings.Repeat(\" \", 44-suf.Len()-len(timing)))\n+\tpad := 44 - suf.Len() - len(timing)\n+\tif pad > 0 {\n+\t\... | 2023-11-21T17:48:20 |
ggml-org/llama.cpp | c5023daf607c578d6344c628eb7da18ac3d92d32 | e7da30b584dc1f2ee0414c4a1298ce64eef97e8d | opencl: support imrope (#16914)
* opencl: support imrope
* opencl: fix whitespace | [
{
"path": "ggml/src/ggml-opencl/ggml-opencl.cpp",
"patch": "@@ -8399,6 +8399,7 @@ static void ggml_cl_rope(ggml_backend_t backend, const ggml_tensor * src0, const\n const bool is_neox = mode & 2;\n const bool is_mrope = mode & GGML_ROPE_TYPE_MROPE;\n const bool is_vision = mode == GGML_ROPE_TYPE... | 2025-11-03T19:47:57 |
denoland/deno | 0b38d25ba7c1893757e15fbb2a68537b0191321f | cfc0451d9552d374441b73f322e99a0c3518a5e6 | fix(ext/node): make `child_process` stdio streams Socket instances (#31975)
This PR fixes child process stdio streams (`stdin`, `stdout`, `stderr`)
to be instances of `Socket` from `node:net`, matching Node.js behavior. | [
{
"path": "ext/node/polyfills/internal/child_process.ts",
"patch": "@@ -156,6 +156,8 @@ function flushStdio(subprocess: ChildProcess) {\n // StreamBase, so it can be used with node streams\n class StreamResource implements StreamBase {\n #rid: number;\n+ #isUnref = false;\n+ #pendingPromises: Set<Promis... | 2026-02-02T18:25:21 |
huggingface/transformers | 6efc1799c1d0665c41717c555f3551d974e4d61a | 325810e7fccf8273599c58a525ae0011ea8ba3e6 | [kernels] Fix XPU layernorm kernel (#41583)
* fix
* add comment
* better fix
* style
* Update src/transformers/modeling_utils.py
Co-authored-by: Marc Sun <57196510+SunMarc@users.noreply.github.com>
---------
Co-authored-by: Marc Sun <57196510+SunMarc@users.noreply.github.com> | [
{
"path": "src/transformers/integrations/hub_kernels.py",
"patch": "@@ -19,6 +19,7 @@\n \n from ..modeling_flash_attention_utils import lazy_import_flash_attention\n from ..utils import logging\n+from ..utils.import_utils import is_kernels_available\n from .flash_attention import flash_attention_forward\n \... | 2025-11-04T15:59:07 |
ggml-org/llama.cpp | e7da30b584dc1f2ee0414c4a1298ce64eef97e8d | ed8aa63320393512bdcfe4b05b5ae01ba91888e1 | fix: Viewing multiple PDF attachments (#16974) | [
{
"path": "tools/server/webui/src/lib/components/app/chat/ChatAttachments/ChatAttachmentPreviewDialog.svelte",
"patch": "@@ -134,6 +134,15 @@\n \t\t}\n \t}\n \n+\t$effect(() => {\n+\t\tif (open) {\n+\t\t\tpdfImages = [];\n+\t\t\tpdfImagesLoading = false;\n+\t\t\tpdfImagesError = null;\n+\t\t\tpdfViewMode = ... | 2025-11-03T17:53:26 |
vuejs/vue | 38810d8fd03b1859854623b2a7dd30506dc3c7bf | 5a617cc404ea902bc1bbd2be9c91596e2df6fffa | Support auto-prefixed style value as array (client/ssr) (#5460)
* support auto-prefixed style value as array (client/ssr)
* adjust test case | [
{
"path": "src/platforms/web/runtime/modules/style.js",
"patch": "@@ -12,7 +12,17 @@ const setProp = (el, name, val) => {\n } else if (importantRE.test(val)) {\n el.style.setProperty(name, val.replace(importantRE, ''), 'important')\n } else {\n- el.style[normalize(name)] = val\n+ const normali... | 2017-04-17T12:49:10 |
ollama/ollama | 6452e2ecb83ae03b1c504e09b6ca3ce9868d0c45 | aabd71aede99443d5858213eec4e8d4c10713c55 | fix cases where progress bar would not be fixed size | [
{
"path": "progress/bar.go",
"patch": "@@ -89,17 +89,13 @@ func (b *Bar) String() string {\n \n \tfmt.Fprintf(&suf, \")\")\n \n-\telapsed := time.Since(b.started)\n \tvar timing string\n \tif stats.value > b.initialValue && stats.value < b.maxValue {\n-\t\ttiming = fmt.Sprintf(\"[%s:%s]\", formatDuration(el... | 2023-11-21T17:07:25 |
denoland/deno | cfc0451d9552d374441b73f322e99a0c3518a5e6 | 22a5f7109df9c124c14fe90da6e4f054f974dc8a | fix: support DENO_SERVE_ADDRESS not being applied to the first server (#31982) | [
{
"path": "ext/http/00_serve.ts",
"patch": "@@ -733,7 +733,6 @@ function serve(arg1, arg2) {\n if (serveAddressOverrideConsumed) {\n return serveInner(options, handler);\n }\n- serveAddressOverrideConsumed = true;\n \n const {\n 0: overrideKind,\n@@ -742,6 +741,8 @@ function serve(arg1, arg2)... | 2026-02-02T15:42:38 |
huggingface/transformers | 325810e7fccf8273599c58a525ae0011ea8ba3e6 | 9a19171fad3025f57fae72d8f3598f44b68102e5 | add fuyu fast image processors (#41817)
* added fast processor for fuyu (#36978)
* updated docs for fuyu model (#36978)
* updated test_image_processing and image_processing_fuyu_fast
* updated fuyu.md and image_processing_fuyu_fast (#36978)
* updated test_image_processing_fuyu (#36978)
* formatted image_processi... | [
{
"path": "docs/source/en/model_doc/fuyu.md",
"patch": "@@ -75,11 +75,11 @@ A processor requires an image_processor and a tokenizer. Hence, inputs can be lo\n from PIL import Image\n from transformers import AutoTokenizer\n from transformers.models.fuyu.processing_fuyu import FuyuProcessor\n-from transforme... | 2025-11-04T15:45:02 |
ggml-org/llama.cpp | fcfce040e816c542f374ad51461b3561d73c4bc9 | ee3a5a10adf9e83722d1914dddc56a0623ececaf | ggml : LoongArch fixes (#16958)
* Fix test-quantize-fns f16 and q4_0 failed when use LSX
* Fix LoongArch set float intrinsic when use LSX/LASX | [
{
"path": "ggml/src/ggml-cpu/arch/loongarch/quants.c",
"patch": "@@ -700,7 +700,8 @@ void ggml_vec_dot_q4_0_q8_0(int n, float * GGML_RESTRICT s, size_t bs, const voi\n for (; ib + 1 < nb; ib += 2) {\n \n // Compute combined scale for the block 0 and 1\n- const __m128 d_0_1 = (__m128)__lsx... | 2025-11-03T06:40:02 |
Subsets and Splits
Assembly Language GitHub Issues
Retrieves a sample of assembly-language related commits with their details, but doesn't provide meaningful analysis or patterns beyond basic filtering.
Swift Compiler Issues Analysis
Retrieves all training data for the Swift programming language repository, providing basic filtering but offering limited analytical insight beyond identifying relevant code examples.